\name{Friedman}
\alias{dFriedman}
\alias{pFriedman}
\alias{qFriedman}
\alias{rFriedman}
\alias{sFriedman}
\title{Friedman's chi-square}
\description{
  Density, distribution function, quantile function, random generator and summary function for Friedman's chi square.
}
\usage{
dFriedman(x, r, N, log=FALSE)
pFriedman(q, r, N, lower.tail=TRUE, log.p=FALSE)
qFriedman(p, r, N, lower.tail=TRUE, log.p=FALSE)
rFriedman(n, r, N)
sFriedman(r, N)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{r}{vector of number of treatments}
	\item{N}{(N >= 2) vector of number of replications of each treatment}
	\item{log, log.p}{  logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{  logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\details{
	The Freidman chi-squared is used for nonparametric ANOVA. The data in N rows of an \eqn{N \times r}{N x r} table are ranked separately such that the ranks take the values from 1 to r in the N different rows. The distributions are obtained on the assumption that there is no relationship between the N rows. 

Formulae:

Let \eqn{R_j}{Rj} be the sum of ranks for treatment \eqn{j (j=1\dots r)}{j (j=1 \ldots r)}, then the Friedman statistic is 

\deqn{
x=\frac{12}{N r (r+1)}\sum_{j=1}^{r}R_j^2 -3N(r+1)}{x=[12/(N r (r+1))]Sum(1 \ldots r)(Rj^2) - 3 N (r+1)}

this is asymptotically equivalent to a \eqn{\chi^2}{chi squared} random variable. One may also calculate the chi squared statistic for the usual analysis of variance which gives 

\deqn{
F=\frac{(N-1)x}{N(r-1)-x}}{F=((N-1) x)/(N (r-1)-x)}

which may be used with the F distribution functions in R for degrees of freedom \eqn{(r-1)} and \eqn{(N-1)(r-1)}.

}
\value{
  The output values conform to the output from other such functions in \R. \code{dFriedman()} gives the density, \code{pFriedman()} the distribution function and \code{qFriedman()} its inverse. \code{rFriedman()} generates random numbers. \code{sFriedman()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
}

\note{
Exact calculations are made for the following values of the parameters:

\tabular{ll}{
	r \tab N \cr
	2 \tab 100 \cr
	3 \tab 30 \cr
	4 \tab 15 \cr
	5 \tab 8 
}
These exact calculations are made using the algorithm of Kendall and Smith (1939). 

The incomplete beta, with continuity correction, is used for calculations outside these ranges.  Some appreciation for the accuracy of the approximation may be obtained by comparing the calculated values with exact tables such as Odeh (1977).  Iman and Davenport (1980) have studied the accuracy of various approximations.
}


\references{
Kendall, M. and Smith, B.B. (1939). The problem of m rankings. \emph{Ann. Math. Stat.} \bold{10.} 275-287.

Iman, R.L. and Davenport, J.M. (1980). Approximations of the critical region of the Friedman statistic. \emph{Comm. Stat. Theor. Meth.} \bold{A9(6).} 571-595.

Odeh, R.E. (1977). Extended tables of the distribution of Friedman's S-statistic in the two-way layout. \emph{Commun. Statist.-Simula. Computa.} \bold{B6(1).} 29-48.

}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

pFriedman(2, r=5, N=10)
pFriedman(c(.8,3.5,9.3), r=5, N=10) ## approximately 5\% 50\% and 95\%
sFriedman(r=5, N=10)
plot(function(x)dFriedman(x, r=5, N=10),0,10)


}
\keyword{distribution}\eof
\name{Johnson}
\alias{dJohnson}
\alias{pJohnson}
\alias{qJohnson}
\alias{rJohnson}
\alias{sJohnson}
\alias{moments}
\alias{JohnsonFit}
\title{The Johnson distributions}
\description{
  Density, distribution function, quantile function, random generator and summary function for the Johnson distributions.
}
\usage{
dJohnson(x, parms, log=FALSE)
pJohnson(q, parms, lower.tail=TRUE, log.p=FALSE)
qJohnson(p, parms, lower.tail=TRUE, log.p=FALSE)
rJohnson(n, parms)
sJohnson(parms)
JohnsonFit(t,moment="quant") 
moments(x)
}
\arguments{
	\item{x,q}{vector of quantities}
	\item{t}{observation vector, t=x, or moment vector, t=[mean,m2,m3,m4]}
	\item{p}{vector of probabilities}
	\item{n}{vector of numbers of observations}
	\item{parms}{list or list of lists each containing output of JohnsonFit()}
	\item{moment}{character scalar specifying t: "quant" (default), or "use," or "find"}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\value{
  The output values conform to the output from other such functions in \R. \code{dJohnson()} gives the density, \code{pJohnson()} the distribution function and \code{qJohnson()} its inverse. \code{rJohnson()} generates random numbers. \code{sJohnson()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
\cr
\code{moments()} calculates the moment statistics of x as a vector with elements (mu, sigma, skew, kurt), where mu is the mean of x, sigma the SD of x with divisor \code{length(x)}, skew is the skewness and kurt the kurtosis. 
\cr
	\code{JohnsonFit()} outputs a list containing the Johnson parameters (gamma, delta, xi, lambda, type), where type is one of the Johnson types: "SN", "SL", "SB", or "SU". \code{JohnsonFit()} does this using 5 order statistics when moment="quant", when moment="find" it does this by using the first four moments of t calculated by the function \code{moments()}, when moment="use" it assumes that the vector t is [mean,m2,m3,m4], where mi is the ith moment about the mean. 
\cr
Fitting by moments is difficult numerically and often \code{JohnsonFit()} will report an error.
}

\details{
	The Johnson system (Johnson 1949) is a very flexible system for describing statistical distributions. It is defined by

\deqn{z=\gamma+\delta \log{f(u)}, u=(x-\xi)/\lambda}{z=gamma+delta log(f(u)), with u=(x-xi)/lambda}

and where \eqn{f( )} has four possible forms:

\tabular{ll}{
	SL:\tab \eqn{f(u)=u} the log normal \cr
	SB:\tab \eqn{f(u)=u+\sqrt{1+u^2}}{f(u)=u+sqrt(1+u^2)} an unbounded distribution\cr
	SU:\tab \eqn{f(u)=u/(1-u)} a bounded distribution\cr
	SN:\tab \eqn{\exp(u)} the normal
}

Estimation of the Johnson parameters may be done from quantiles. The procedure of Wheeler (1980) is used.

They may also be estimated from the moments.  Applied Statistics algorithm 99, due to Hill, Hill, and Holder (1976) has been translated into C for this implementation.  
}

\references{

Hill, I.D., Hill, R., and Holder, R.L. (1976). Fitting Johnson curves by moments. \emph{Applied Statistics.} AS99.

Johnson, N.L. (1949). Systems of frequency curves generated by methods of translation. \emph{Biometrika,} \bold{36.} 149-176.

Wheeler, R.E. (1980). Quantile estimators of Johnson curve parameters. \emph{Biometrika.} \bold{67-3} 725-728

}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

xx<-rnorm(500)
parms<-JohnsonFit(xx)
sJohnson(parms)
plot(function(xx)dJohnson(xx,parms),-2,2)
pJohnson(1,parms)
parms2<-JohnsonFit(rexp(50))
qJohnson(p=0.5,list(parms,parms2))

## JohnsonFit with moment="find" and moment="use" is not always possible,
## and even when possible, may produce odd results.
## parms<-JohnsonFit(x,moment="find")

parms<-JohnsonFit(c(0,1,-.5,4),moment="use")

sJohnson(parms) 

# Fit illustration
data(cars)
xx<-cars$speed
parms<-JohnsonFit(xx)
hist(xx,freq=FALSE)
plot(function(x)dJohnson(x,parms),0,25,add=TRUE)


}
\keyword{distribution}\eof
\name{Kendall}
\alias{dKendall}
\alias{pKendall}
\alias{qKendall}
\alias{rKendall}
\alias{sKendall}
\title{The distribution of Kendall's tau}
\description{
  Density, distribution function, quantile function, random generator and summary function for Kendall's tau.
}
\usage{
dKendall(x, N, log=FALSE)
pKendall(q, N, lower.tail=TRUE, log.p=FALSE)
qKendall(p, N, lower.tail=TRUE, log.p=FALSE)
rKendall(n, N)
sKendall(N)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{N}{vector number of treatments}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\value{
  The output values conform to the output from other such functions in \R. \code{dKendall()} gives the density, \code{pKendall()} the distribution function and \code{qKendall()} its inverse. \code{rKendall()} generates random numbers. \code{sKendall()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
}

\details{

There are two categories with N treatments each.  The treatments are ranked for each category, and then sorted according to the ranks for the first category.  This produces a 2 by N array in which the numbers in the first row are increasing from 1 to N.  The array is scanned, and every time two adjacent ranks in the second row are not in order, they are exchanged.  The scanning is repeated until the second row is in increasing order.  Let s denote the number of exchanges, then Kendall's tau is given by

\deqn{\tau=1-\frac{4s}{N(N-1)}}{tau=1-4 s/(N (N-1))}
}

This too is a product-moment correlation coefficient.  See Kendall (1975), Chapter 2.  Other methods for calculating the statistic are also discussed there.

The calculated values are exact for \eqn{N < 13}, thereafter an Edgeworth expansion is used.

}
\references{
Kendall, M. (1975). \emph{Rank Correlation Methods.} Griffin, London.
}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

pKendall(0, N=10)
pKendall(c(-.42,0.02,.42), N=10) ## approximately 5\% 50\% and 95\% 
qKendall(.95,N=c(10,20))
sKendall(N=10)
plot(function(x)dKendall(x, N=10),-0.5,0.5)


}
\keyword{distribution}\eof
\name{KruskalWallis}
\alias{Kruskal}
\alias{KruskalWallis}
\alias{dKruskalWallis}
\alias{pKruskalWallis}
\alias{qKruskalWallis}
\alias{rKruskalWallis}
\alias{sKruskalWallis}
\title{Kruskall-Wallis distribution}
\description{
  Density, distribution function, quantile function, random generator and summary function for the  Kruskal-Wallis test. 
}
\usage{
dKruskalWallis(x, c, N, U, log=FALSE)
pKruskalWallis(q, c, N, U, lower.tail=TRUE, log.p=FALSE)
qKruskalWallis(p, c, N, U, lower.tail=TRUE, log.p=FALSE)
rKruskalWallis(n, c, N, U)
sKruskalWallis(c, N, U)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{c}{vector number of treatments}
	\item{N}{vector total number of observations}
	\item{U}{vector sum of reciprocals of the number of the c sample sizes}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\value{
  The output values conform to the output from other such functions in \R. \code{dKruskalWallis()} gives the density, \code{pKruskalWallis()} the distribution function and \code{qKruskalWallis()} its inverse. \code{rKruskalWallis()} generates random numbers. \code{sKruskalWallis()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis. 
}

\details{

This is a one-way layout with, perhaps, unequal sample sizes for each treatment. There are c treatments with sample sizes \eqn{n_j, j=1 \dots c}{nj, j=1 \ldots c}. The total sample size is \eqn{N=\sum_1^c n_j}{N=Sum(1 \ldots c)nj}. The distribution depends on c, N, and U, where \eqn{U=\sum_1^c (1/n_j)}{U=Sum(1 \ldots c)(1/nj)}. 

Let \eqn{R_j}{Rj} be the sum of the ranks for treatment \eqn{j (j=1\dots c)}{j (j=1 \ldots c)} then the Kruskal-Wallis statistic is

\deqn{x=\frac{12}{N(N+1)}\sum_{j=1}^{c}\frac{R_j^2}{n_j} - 3(N+1)}{x=(12/(N (N-1))Sum(1 \ldots c)(Rj/nj) - 3 (N+1)}

This is asymptotically equivalent to a chi-squared variable with c-1 degrees of freedom.

The original paper is Kruskal and Wallis (1952) with errata appearing in Kruskal and Wallis (1953).  No attempt is made to calculate exact values, rather an incomplete beta approximation is used following Wallace (1959).

}




\references{

Kruskal, W.H. and Wallis, W.A. (1952) Use of ranks in one-criterion variance analysis. \emph{Jour. Am. Stat. Assoc.} \bold{47.} 583-634

Kruskal, W.H. and Wallis, W.A. (1952) Errata to Use of ranks in one-criterion variance analysis. \emph{Jour. Am. Stat. Assoc.} \bold{48.} 907-911.


Wallace, D.L. (1959). Simplified beta-approximations to the Kruskal-Wallis H test. \emph{Jour. Am. Stat. Assoc.} \bold{54.} 225-230.

}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

# Assuming three treatments, each with a sample size of 5.
pKruskalWallis(1, 3, 15, 0.6)
pKruskalWallis(c(.1,1.5,5.7), 3, 15, 0.6) ## approximately 5\% 50\% and 95\%
sKruskalWallis(3, 15, 0.6)
plot(function(x)dKruskalWallis(x, 3, 15, 0.6),0.5,8)

}
\keyword{distribution}\eof
\name{MWC1019}
\alias{rMWC1019}
\title{A very long period pseudo-random generator}
\description{
  A pseudo-random number generator with a period exceeding ``10e9824'' due to George Marsaglia
}
\usage{
rMWC1019(n, new.start=FALSE, seed=556677)
}
\arguments{
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{new.start}{logical scalar. If TRUE the generator will be started afresh using the seed}
	\item{seed}{scalar 32 bit integer used as the generator seed}
}
\value{
  generates a vector of random numbers. 
}


\details{

The following is an email from George Marsaglia on this generator: 

``MCW1019  will provide random 32-bit integers at the rate of 300 million per second (on a 850MHz PC).

The period of MWC1029 exceeds 10e9824, making it  billions and billions ... and billions times as long as the highly touted longest-period RNG, the Mersenne twister.   It is also several times as fast and takes a few lines rather than  several pages of code.   (This is not to say that the Mersenne twister is not a good RNG; it is.  I just do not equate complexity of code  with randomness.   It is the complexity of the underlying randomness that counts.)

As for randomness, it passes all tests in The Diehard Battery of Tests of Randomness \url{http://stat.fsu.edu/pub/diehard} as well as three new tough tests I have developed with the apparent property that a RNG that passes  tuftsts.c will pass all the tests in Diehard.

MWC1019 has the property that every possible sequence of 1018 successive 32-bit integers will appear somewhere in the full period,  for those concerned with the ``equi-distribution'' in dimensions 2,3,...1016,1017,1018.''

NOTE:

	The generator requires 1019 initial 32 bit random values to start. These are provided by using Marsaglia's MWC generator. By setting new.start=FALSE, the sequence may be sampled in blocks. \R specifies an internal array dimension of 625 for seed length, and thus at the present time, it is not possible to implement this generator using the .Random.seed mechanism. In this implementation, rMWC1019() seems to be about twice as fast as the Mersenne-Twister implemented in \R.


}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

rMWC1019(50,new.start=TRUE,seed=492166)
rMWC1019(50)

}
\keyword{distribution}\eof
\name{NormalScore}
\alias{NormScore}
\alias{dNormScore}
\alias{pNormScore}
\alias{qNormScore}
\alias{rNormScore}
\alias{sNormScore}
\alias{normOrder}
\title{Normal Scores distribution}
\description{
  Density, distribution function, quantile function, random generator and summary function for the normal scores test. A function to calculate expected values of normal order statistics is included.
}
\usage{
dNormScore(x, c, N, U, log=FALSE)
pNormScore(q, c, N, U, lower.tail=TRUE, log.p=FALSE)
qNormScore(p, c, N, U, lower.tail=TRUE, log.p=FALSE)
rNormScore(n, c, N, U)
sNormScore(c, N, U)
normOrder(N)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{c}{vector number of treatments}
	\item{N}{vector total number of observations}
	\item{U}{vector sum of reciprocals of the number of the c sample sizes}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\value{
  The output values conform to the output from other such functions in \R. \code{dNormScore()} gives the density, \code{pNormScore()} the distribution function and \code{qNormScore()} its inverse. \code{rNormScore()} generates random numbers. \code{sNormScore()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis. \code{normOrder()} gives the expected values of the normal order statistics for a sample of size N.
}

\details{
This is the Kruskal-Wallis statistic with ranks replaced by the expected values of normal order statistics. There are c treatments with sample sizes \eqn{n_j, j=1 \dots c}{nj, j=1 \ldots c}. The total sample size is \eqn{N=\sum_1^c n_j}{N=Sum nj}. The distribution depends on c, N, and U, where \eqn{U=\sum_1^c (1/n_j)}{U=Sum (1/nj)}. 

Let \eqn{e_N(k)}{eN(k)} be the expected value of the \eqn{k_{th}}{kth} smallest observation in a sample of N independent normal variates. Rank all observations together, and let \eqn{R_{ij}}{Rij} denote the rank of observation \eqn{X_{ij}}{Xij}, \eqn{i=1 \dots n_j}{i=1 \ldots nj} for treatment \eqn{j=1 \dots c}{j=1 \ldots c}, then the normal scores test statistic is

\deqn{x=(N-1)\frac{1}{\sum_{k=1}^{N} e_N(k)^2} \sum_{j=1}^{c}\frac{S_j^2}{n_j}}{x=(N-1)[1/Sum(1 \ldots N)(eN(k)^2)]Sum(1 \ldots c)[(Sj^2)/nj]}

where \eqn{S_j=\sum_{i=1}^{n_j}(e_N(R_{ij}))}{Sj=Sum(1 \ldots nj)(eN(Rij))}.

See Lu and Smith (1979) for a thorough discussion and some exact tables for small r and n.  The calculations made here use an incomplete beta approximation -- the same one used for Kruskal-Wallis, only differing in the calculation of the variance of the statistic.

The expected values of the normal order statistics use a modification of M.Maechler's C version of the Fortran algorithm given by Royston (1982). Spot checking the values against Harter (1969) confirms the accuracy to 4 decimal places as claimed by Royston.

}




\references{

Harter, H.L. (1969). \emph{Order statistics and their use in testing and estimation, volume 2.} U.S. Supp. of Doc. 

Lu, H.T. and Smith, P.J. (1979) Distribution of normal scores statistic for nonparametric one-way analysis of variance. \emph{Jour. Am Stat. Assoc.} \bold{74.} 715-722.

Royston, J.P. (1982). Expected normal order statistics (exact and approximate) AS 177. \emph{Applied Statistics.} \bold{31.} 161-165. 

}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

#Assuming three treatments, each with a sample size of 5
pNormScore(2, 3, 15, 0.6)
pNormScore(c(0.11,1.5,5.6), 3, 15, 0.6) ## approximately 5\% 50\% and 95\%
sNormScore(3, 15, 0.6)
plot(function(x)dNormScore(x,c=5, N=15, U=0.6),0,5)

}
\keyword{distribution}\eof
\name{Pearson}
\alias{Pearson}
\alias{dPearson}
\alias{pPearson}
\alias{qPearson}
\alias{rPearson}
\alias{sPearson}
\title{The Pearson product moment correlation coefficient}
\description{
  Density, distribution function, quantile function, random generator and summary function for the distribution of Pearson's product moment correlation.
}
\usage{
dPearson(x, N, rho=0.0, log=FALSE)
pPearson(q, N, rho=0.0, lower.tail=TRUE, log.p=FALSE)
qPearson(p, N, rho=0.0, lower.tail=TRUE, log.p=FALSE)
rPearson(n, N, rho=0.0)
sPearson(N, rho=0.0)
}

\arguments{
	\item{x,q}{vector of sample correlations}
	\item{p}{vector of probabilities}
	\item{rho}{vector of population correlations}
	\item{N}{vector of numbers of observations, \eqn{(N > 3)}}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[R <= r]}, otherwise, \eqn{P[R > r]}}
}

\value{
  The output values conform to the output from other such functions in \R. \code{dPearson()} gives the density, \code{pPearson()} the distribution function and \code{qPearson()} its inverse. \code{rPearson()} generates random numbers. \code{sPearson()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
}



\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

pPearson(0.5, N=10)
pPearson(q=0.5, N=10, rho=0.3) 
sPearson(N=10)
plot(function(x)dPearson(x,N=10,rho=0.7),-1,1)

}
\keyword{distribution}\eof
\name{Spearman}
\alias{dSpearman}
\alias{pSpearman}
\alias{qSpearman}
\alias{rSpearman}
\alias{sSpearman}
\title{Spearman's rho}
\description{
  Density, distribution function, quantile function, random generator and summary function for Spearman's rho.
}
\usage{
dSpearman(x, r, log=FALSE)
pSpearman(q, r,  lower.tail=TRUE, log.p=FALSE)
qSpearman(p, r,  lower.tail=TRUE, log.p=FALSE)
rSpearman(n, r)
sSpearman(r)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{r}{(r >= 3) vector of number of observations}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\details{

	Spearman's rho is the rank correlation coefficient between r pairs of items. It ranges from -1 to 1. Denote by d, the sum of squares of the differences between the matched ranks, then x is given by:

\deqn{1-\frac{6d}{r(r^2-1)}}{1-6 d /(r(r^2-1))}

This is, in fact, the product-moment correlation coefficient of rank differences.  See Kendall (1975), Chapter 2. It is identical to Friedman's chi-squared for two treatments scaled to the -1, 1 range -- if X is the Friedman statistic, then \eqn{\rho=frac{X}{r-1)-1}}{rho = X/(r-1) -1}.

Exact calculations are made for \eqn{r \le 100}{r <= 100}

These exact calculations are made using the algorithm of Kendall and Smith (1939). 

The incomplete beta, with continuity correction, is used for calculations outside this range.  
}

\value{
  The output values conform to the output from other such functions in \R. \code{dSpearman()} gives the density, \code{pSpearman()} the distribution function and \code{qSpearman()} its inverse. \code{rSpearman()} generates random numbers. \code{sSpearman()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
}



\references{

Kendall, M. (1975). \emph{Rank Correlation Methods.} Griffin, London.

Kendall, M. and Smith, B.B. (1939). The problem of m rankings. \emph{Ann. Math. Stat.} \bold{10.} 275-287.


}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

pSpearman(.95, 10)
pSpearman(c(-0.55,0,0.55), 10) ## approximately 5\% 50\% and 95\% 
sSpearman(10)
plot(function(x)dSpearman(x, 10),-.9,.9)



}
\keyword{distribution}\eof
\name{SuppDists-internal}
\alias{makeStatList}
\title{Internal SuppDists function}
\description{
 Internal SuppDists function
}
\usage{
makeStatList(head, mn, med, var, mod, third, fourth, dig) 
}
\details{
  This is not to be called by the user.
}
\keyword{distribution}
\keyword{internal}
\eof
\name{ghyper}
\alias{dghyper}
\alias{pghyper}
\alias{qghyper}
\alias{rghyper}
\alias{sghyper}
\alias{tghyper}
\alias{Generalized hypergeometric}
\alias{Negative hypergeometric}
\alias{Inverse hypergeometric}
\alias{Hypergeometric waiting time}
\alias{Beta-binomial}
\alias{Beta-negative-binomial}
\alias{Beta-Pascal}
\alias{Generalized Waring} 


\title{Generalized hypergeometric distributions}
\description{
  Density, distribution function, quantile function, random generator and summary function for generalized hypergeometric distributions.
}
\usage{
dghyper(x, a, k, N, log=FALSE)
pghyper(q, a, k, N, lower.tail=TRUE, log.p=FALSE)
qghyper(p, a, k, N, lower.tail=TRUE, log.p=FALSE)
rghyper(n, a, k, N)
sghyper(a, k, N)
tghyper(a, k, N) ## scalar arguments only
}
\arguments{
	\item{x,q,n}{vector of non-negative \bold{integer} quantities}
	\item{p}{vector of probabilities}
	\item{a}{vector of real values giving the first column total}
	\item{k}{vector  of real values giving the first row total}
	\item{N}{vector of real values giving the grand total}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\value{
  The output values conform to the output from other such functions in R. \code{dghyper()} gives the density, \code{pghyper()} the distribution function and \code{qghyper()} its inverse. \code{rghyper()} generates random numbers. \code{sghyper()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
\cr
	The function \code{tghyper()} returns the hypergeometric type and the range of values for x.	
}


\details{

The basic representation is in terms of a two-way table:

\tabular{ccc}{
x \tab  k-x \tab  k\cr
a-x \tab  b-k+x \tab  N-k\cr
a \tab     b \tab  N}

and the associated hypergeometric probability \eqn{P(x)=C_x^a C_{k-x}^b / C_k^N}{P(x)=choose(a, x) choose(b, k-x) / choose(N, k)}.

The table is constrained so that rows and columns add to the margins.  In all cases x is an integer or zero, but meaningful probability distributions occur when the other parameters are real. Johnson, Kotz and Kemp (1992) give a general discussion.

Kemp and Kemp (1956) classify the possible probability distributions that can occur when real values are allowed, into eight types. The \emph{classic} hypergeometric with integer values forms a ninth type.  Five of the eight types correspond to known distributions used in various contexts.  Three of the eight types, appear to have no practical applications, but for completeness they have been implemented.  

The Kemp and Kemp types are defined in terms of the ranges of the a, k, and N parameters and are given in \code{\link{ghyper.types}}. The function \code{tghyper()} will give details for specific values of a, k, and N.
 


These distributions apply to many important problems, which has lead to a variety of names:

The Kemp and Kemp types IIA and IIIA are known as:
\itemize{
\item Negative hypergeometric
\item	Inverse hypergeometric
\item	Hypergeometric waiting time
\item	Beta-binomial
}

The advantages of the conditional argument are considerable. Consider a few examples:

\enumerate{
\item Future event: Consider two events which have occurred u and v times respectively.  The distribution function of x occurrences of the first event in a sample of k new trials is calculated.  Here a = -u-1, and N = -u-v-2. 

Example: Suppose Toronto has won 3 games and Atlanta 1 in the World Series. What is the probability that Toronto will win the series by taking 2 or more of the remaining 3 games?

\item Exceedance: Consider two samples of size m and k, then the distribution function of x, the number of elements out of k which exceed the r th largest element in the size m sample is calculated.  Here a = -r, and N = -m-1. 

Example: Suppose that only once in the last century has the high-water mark at the St. Joe bridge exceeded 12 feet, what is the probability that it will not do so in the next ten years?

\item Waiting time: Consider an urn with T balls, m of which are white, and that drawing with replacement is continued until w white balls are obtained, then the distribution function of x, the number of balls in excess of w that must be drawn is desired.  Here a = -w , N = -m-1, and k = T - m. 

Example: Suppose a lot of 100 contains 5 defectives. What is the mean number of items that must be inspected before a defective item is found?

\item Mixture: Suppose x has a binomial distribution with parameter p, and number of trials k.  Suppose that p is not fixed, but itself distributed like a beta variable with parameters A and B, then the distribution of x is calculated with a = -A and N = -A -B.
}
 



Names for Kemp and Kemp type IV are:
\itemize{
\item	Beta-negative-binomial
\item	Beta-Pascal
\item	Generalized Waring 
}

One application is accidents:

Suppose accidents follow a Poisson distribution with mean L, and suppose L varies with individuals according to accident proneness, m.  In particular, suppose L follows a gamma distribution with parameter r and scale factor m , and that the scale factor n itself follows a beta distribution with parameters A and B, then the distribution of accidents, x, is beta-negative-binomial with a = -B, k = -r , and N = A -1.  See Xekalki (1983) for a discussion of this as well as a discussion of accident models for proneness, contagion and spells.



}

\references{

Johnson, N.L., Kotz, S. and Kemp, A. (1992) \emph{Univariate discrete distributions}. Wiley, N.Y.
 
Kemp, C.D., and Kemp, A.W. (1956). Generalized hypergeometric distributions. \emph{Jour. Roy. Statist. Soc. B.} \bold{18.} 202-211.



Xekalaki, E. (1983). The univariate generalized Waring distribution in relation to accident theory: proneness, spells or contagion. \emph{Biometrics.} \bold{39.}  887-895.
}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

tghyper(a=4, k=4, N=10) 		## classic
tghyper(a=4.1, k=5, N=10) 		## type IA(i) Real classic
tghyper(a=5, k=4.1, N=10) 		## type IA(ii) Real classic
tghyper(a=4.2, k=4.6, N=12.2) 		## type IB
tghyper(a=-5.1, k=10, N=-7) 		## type IIA
tghyper(a=-0.5, k=5.9, N=-0.7) 		## type IIB
tghyper(a=10, k=-5.1, N=-7) 		## type IIIA Negative hypergeometric
tghyper(a=5.9, k=-0.5, N=-0.7) 		## type IIIB
tghyper(a=-1, k=-1, N=5) 		## type IV Generalized Waring

sghyper(a=-1, k=-1, N=5)
plot(function(x)dghyper(x,a=-1,k=-1,N=5),0,5)

#Fisher's exact test: contingency table with rows (1,3),(3,1) 
pghyper(1,4,4,8)
pghyper(3,4,4,8,lower.tail=FALSE)



#Beta-binomial applications:

#Application examples:
tghyper(-4,3,-6)
pghyper(2,-4,3,-6,lower=FALSE)
pghyper(0,-2,10,-101)
sghyper(-1,95,-6)$Mean+1



}
\keyword{distribution}\eof
\name{ghyper.types}
\alias{ghyper.types}


\title{Kemp and Kemp generalized hypergeometric types}
\description{
	Generalized hypergeometric types as given by Kemp and Kemp	
}

\section{Two-way table}{

The basic representation is in terms of a two-way table:

\tabular{ccc}{
x \tab  k-x \tab  k \cr
a-x \tab  b-k+x \tab  N-k \cr
  a \tab     b \tab  N
}

and the associated hypergeometric probability \eqn{P(x)=C_x^a C_{k-x}^b / C_k^N}{P(x)=choose(a, x) choose(b, k-x) / choose(N, k)}.

The types are classified according to ranges of a, k, and N.

}
\section{Kemp and Kemp types}{

Minor modifications in the definition of three of the types have been made to avoid numerical difficulties. Note, J denotes a nonnegative integer.


\tabular{ll}{
[Classic] \tab \cr
	\tab \eqn{0<a, 0<N, 0<k} \cr
 	\tab	integers: a, N, k.\cr
	\tab	\eqn{max(0,a+k-N)  \le  x  \le  min(a,k)}{max(0,a+k-N) <= x <= min(a,k)}\cr
[IA(i)] (Real classic) \tab at least one noninteger parameter\cr
	\tab \eqn{0<a, 0<N, 0<k, k-1<a<N-(k-1)} \cr
	\tab	integer: k \cr
	\tab \eqn{	0  \le  x  \le  a}{0 <= x <= k}\cr

[IA(ii)] (Real classic)\tab at least one noninteger parameter\cr
	\tab \eqn{0<a, 0<N, 0<k, a-1<k<N-(a-1)} \cr
	\tab integer: a \cr 
	\tab \eqn{0  \le  x  \le  a}{0 <= x <= a} \cr 
	\tab Interchanging a and k transforms this to type IA(i) \cr

[IB] \tab \cr
	\tab \eqn{0<a, 0<N, 0<k, a+k-1<N, J < (a,k) < J+1} \cr
	\tab integer: \eqn{0 \le J}{0 <= J} \cr
	\tab non-integer: a, k \cr
	\tab \eqn{0  <=  x  \dots }{0 <= x \ldots}\cr
	
	\tab NOTE: Kemp and Kemp specify \eqn{-1<N}{-1<N}. \cr
	\tab No practical applications for this distribution. \cr
[IIA] (negative hypergeometric) \tab \cr
	\tab \eqn{a<0, N<a-1,0<k} \cr
	\tab integer: k \cr
	\tab \eqn{0  \le  x  \le  k}{0 <= x <= k} \cr
	
	\tab NOTE: Kemp and Kemp specify \eqn{N<a,  N \ne a-1}{N<a and  N!=(a-1)} \cr
[IIB] \tab \cr
	\tab \eqn{a<0, -1<N<k+a-1, 0<k, J < (k,k+a-1-N) < J+1} \cr

	\tab non-integer: k \cr
	\tab integer: \eqn{0 \le J}{0 <= J} \cr
	\tab \eqn{0  \le  x  ....}{0 <= x \ldots} \cr

	\tab This is a very strange distribution.  Special calculations were used.\cr

	\tab Note: No practical applications.\cr
[IIIA] (negative hypergeometric) \tab \cr
	\tab \eqn{0<a,N<k-1,k<0}\cr
	\tab integer: a\cr
	\tab \eqn{0 \le x \le a}{0  <=  x  <=  a}\cr
	
	\tab Interchanging a and k transforms this to type IIA \cr

	\tab NOTE: Kemp and Kemp specify \eqn{N<k, N \ne k-1}{N<k and N != k-1} \cr

[IIIB]\tab \cr
	\tab  \eqn{0<a,-1<N<a+k-1,k<0, J<(a,a+k-1-N)<J+1} \cr
	\tab non integer: a\cr
	\tab integer: \eqn{0 \le J}{0 <= J}\cr
	\tab \eqn{0 \le x \dots }{0  <=  x \ldots}\cr

	\tab Interchanging a and k transforms this to type IIB \cr
	\tab Note: No practical applications\cr

[IV] (Generalized Waring) \tab \cr
	\tab \eqn{a<0,-1<N, k<0}\cr
	\tab \eqn{0 \le x \dots}{0  <=  x  \ldots}

}


}


\references{

 
Kemp, C.D., and Kemp, A.W. (1956). Generalized hypergeometric distributions. \emph{Jour. Roy. Statist. Soc. B.} \bold{18.} 202-211.
\bold{39.}  887-895.
}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\keyword{distribution}\eof
\name{invGauss}
\alias{inverse Gaussian}
\alias{Wald distribution}
\alias{dinvGauss}
\alias{pinvGauss}
\alias{qinvGauss}
\alias{rinvGauss}
\alias{sinvGauss}
\title{The inverse Gaussian and Wald distributions}
\description{
  Density, distribution function, quantile function, random generator and summary function for the inverse Gaussian and Wald distributions.
}
\usage{
dinvGauss(x, nu, lambda, log=FALSE)
pinvGauss(q, nu, lambda, lower.tail=TRUE, log.p=FALSE)
qinvGauss(p, nu, lambda, lower.tail=TRUE, log.p=FALSE)
rinvGauss(n, nu, lambda)
sinvGauss(nu, lambda)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{vector of numbers of observations}
	\item{nu}{vector real and non-negative parameter -- the Wald distribution results when nu=1}
	\item{lambda}{vector real and non-negative parameter}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\value{
  The output values conform to the output from other such functions in R. \code{dinvGauss()} gives the density, \code{pinvGauss()} the distribution function and \code{qinvGauss()} its inverse. \code{rinvGauss()} generates random numbers. \code{sinvGauss()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
}

\details{

Probability functions:

\deqn{f(x,\nu,\lambda)=\sqrt{\frac{\lambda}{2\pi x^3}}\exp\left[-\lambda\frac{(x-\nu)^2}{2\nu^2 x}\right] \mbox{-- the density}}{f(x,nu,lambda)=sqrt[lambda/(2 pi x^3)]exp[-lambda(x-nu)^2/(2 x nu^2)] -- the density
}

\deqn{F(x,\nu,\lambda)=\Phi\left[\sqrt{\frac{\lambda}{x}}\left(\frac{x}{\nu}-1\right)\right]+e^{2\lambda/\nu}\Phi\left[\sqrt{\frac{\lambda}{x}}\left(\frac{x}{\nu}+1\right)\right] \mbox{-- the distribution function}}{F(x,nu,lambda)=Phi[sqrt(lambda/x)((x/nu)-1)]+exp(2*lambda/nu)*Phi[sqrt(lambda/x)((x/nu)+1)] -- the distribution function}

where \eqn{\Phi[]}{Phi[]} is the standard normal distribution function.


The calculations are accurate to at least seven significant figures over an extended range - much larger than that of any existing tables. We have tested them for \eqn{\lambda / \nu = 10e-20}{(lambda/nu)=10e-20}, and \eqn{\lambda/\nu=10e4}{lambda / nu = 10e4}. Accessible tables are those of Wassan and Roy (1969), which unfortunately, are sometimes good to only two significant digits. Much better tables are available in an expensive CRC Handbook (1989)  these tables are accurate to at least 7 significant digits for \eqn{\lambda/\nu \ge 0.02}{lambda / nu >= 0.02} to \eqn{\lambda/\nu \le 4000}{lambda / nu <= 4000}. 



These are first passage time distributions of Brownian motion with positive drift. See Whitmore and Seshadri (1987) for a heuristic derivation. The Wald (1947) form represents the average sample number in sequential analysis. The distribution has a non-monotonic failure rate, and is of considerable interest in lifetime studies: Ckhhikara and Folks (1977). A general reference is Seshadri (1993). 



This is an extremely difficult distribution to treat numerically, and it would not have been possible without some extraordinary contributions. An elegant derivation of the distribution function is to be found in Shuster (1968). The first such derivation seems to be that of Zigangirov (1962), which because of its inaccessibility, the author has not read. The method of generating random numbers is due to Michael, Schucany, and Haas (1976). The approximation of Whitmore and Yalovsky (1978) makes it possible to find starting values for inverting the distribution. All three papers are short, elegant, and non- trivial. 
}

\references{
Ckhhikara, R.S. and Folks, J.L. (1977) The inverse Gaussian distribution as a lifetime model. \emph{Technometrics.} \bold{19-4.} 461-468. 

CRC Handbook. (1989). \emph{Percentile points of the inverse Gaussian distribution.} J.A. Koziol (ed.) Boca Raton, FL. 

Michael, J.R., Schucany, W.R. and Haas, R.W. (1976). Generating random variates using transformations with multiple roots. \emph{American Statistician.} \bold{30-2.} 88-90. 

Seshadri, V. (1993). \emph{The inverse Gaussian distribution.} Clarendon, Oxford 

Shuster, J. (1968). On the inverse Gaussian distribution function. Jour. \emph{Am. Stat. Assoc.} \bold{63.} 1514-1516. 

Wasan, M.T. and Roy, L.K. (1969). Tables of inverse Gaussian percentage points. \emph{Technometrics.} \bold{11-3.} 591-604. 

Wald, A. (1947). \emph{Sequential analysis.} Wiley, NY 

Whitmore, G.A. and Seshadri, V. (1987). A heuristic derivation of the inverse Gaussian distribution. \emph{American Statistician.} \bold{41-4.} 280-281. 

Whitmore, G.A. and Yalovsky, M. (1978). A normalizing logarithmic transformation for inverse Gaussian random variables. \emph{Technometrics.} \bold{20-2.} 207-208. 

Zigangirov, K.S. (1962). Expression for the Wald distribution in terms of normal distribution. \emph{Radiotech.Electron.} \bold{7.} 164-166. 
}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

pinvGauss(1, 1, 16)
pinvGauss(c(.65,1,1.45), 1, 16) ## approximately 5\% 50\% and 95\%
pars<-sinvGauss(1, 16)
plot(function(x)dinvGauss(x,1, 16),pars$Mean-3*pars$SD,pars$Mean+3*pars$SD)
}
\keyword{distribution}\eof
\name{maxFratio}
\alias{maxFratio}
\alias{dmaxFratio}
\alias{pmaxFratio}
\alias{qmaxFratio}
\alias{rmaxFratio}
\alias{smaxFratio}
\title{The maximum F-ratio distribution}
\description{
  Density, distribution function, quantile function, random generator and summary function for the maximum F-ratio.
}
\usage{
dmaxFratio(x, df, k, log=FALSE)
pmaxFratio(q, df, k, lower.tail=TRUE, log.p=FALSE)
qmaxFratio(p, df, k, lower.tail=TRUE, log.p=FALSE)
rmaxFratio(n, df, k)
smaxFratio(df, k)
}
\arguments{
	\item{x,q}{vector of non-negative quantities}
	\item{p}{vector of probabilities}
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{df}{vector non-negative, integer degrees of freedom}
	\item{k}{vector non-negative, integer number of mean squares}
	\item{log, log.p}{logical vector; if TRUE, probabilities p are given as log(p)}
	\item{lower.tail}{logical vector; if TRUE (default), probabilities are \eqn{P[X <= x]}, otherwise, \eqn{P[X > x]}}
}
\details{
	The maximum F-ratio is the ratio of the largest to the smallest of k independent mean squares, all with the same df. The usual use is to test for homogeneity of normal variances.
}
\value{
  The output values conform to the output from other such functions in \R. \code{dmaxFratio()} gives the density, \code{pmaxFratio()} the distribution function and qmaxFratio its inverse. \code{rmaxFratio()} generates random numbers. \code{smaxFratio()} produces a list containing parameters corresponding to the arguments -- mean, median, mode, variance, sd, third cental moment, fourth central moment, Pearson's skewness, skewness, and kurtosis.
}

\note{

The maximum F-ratio was introduced by Hartley (1950) as a shortcut test of the homogeneity of variances from normal data.  Given a set of k mean squares, each based on the same number of degrees of freedom, df, the test statistic is the ratio of the largest to the smallest.  Several tables have been constructed.  The first by David, H.A. (1952).  Currently the most extensive are those by Nelson (1987).

It is important to note that tests of this sort are substantially dependent on the assumption of normality, and can not be used robustly as can variance ratios in the analysis of variance.
}
\section{Limitations}{

The literature contains no information on numerical procedures for this distribution, with the result that all calculations are slow.

Finding p from x should give results for almost any values of df and k -- of course absolutely enormous values will take a while.

Finding x from p is an iterative calculation dependent on a good starting guess.  Such good guesses have been made for \eqn{df \le 24}{df <= 24} and \eqn{k \le 160}{df <= 160}.  NA will be returned if larger values are attempted.

}

\references{
Hartley, H.O. (1950) The maximum F-ratio as a short cut test for heterogeneity of variance. \emph{Biometrika.} \bold{37.} 308-312.

David, H.A. (1952). Upper 5 and 1\% points of the maximum F-ratio. \emph{Biometrika.} \bold{38.} 422-424.

Nelson, L.S. (1987). Upper 10\%, 5\% and 1\% points of the maximum F-ratio, \emph{Jour. Qual. Tech.} \bold{19-3.} 165-167.

}

\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

pmaxFratio(4, 10, 10)
pmaxFratio(c(2.3, 4, 8.5), 10, 10)	## approximately 5\% 50\% and 95\% 
qmaxFratio(p=.95,df=c(10,20), k=10)
smaxFratio(10, 10) ## Wait for this, it may take a while
plot(function(x)dmaxFratio(x, 10, 10),1,10)

}
\keyword{distribution}\eof
\name{ziggurat}
\alias{rziggurat}
\title{The Ziggurat normal and exponential generator}
\description{
  Generates normal and exponential random pseudo-random numbers by the method of Marsaglia and Tsang.
}
\usage{
rziggurat(n, normal=TRUE, new.start=FALSE, seed=556677)
}
\arguments{
	\item{n}{number of values to generate. If n is a vector, length(n) values will be generated}
	\item{normal}{logical scalar; if TRUE normal values are produced, otherwise exponential values}
	\item{new.start}{logical scalar. If TRUE the generator will be started afresh using the seed}
	\item{seed}{scalar 32 bit starting integer}
}
\value{
  Generates a vector of pseudo random numbers in the range 0 to 1. 
}

\note{
	This implementation running in \R is approximately three times as fast as rnorm().
}

\references{

Marsaglia, George, and Tsang, Wai Wan. 2000. The Ziggurat method for generating random variables. \emph{Journal of Statistical software.} \bold{5-8.} \url{http://www.jstatsoft.org/v05/i08/}
}
\author{
	Bob Wheeler \email{bwheeler@echip.com}
}
\examples{

rziggurat(50,new.start=TRUE)
rziggurat(50)
rziggurat(50,new.start=TRUE)

}
\keyword{distribution}\eof
